package com.temboo.Library.Amazon.EC2;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DescribeSnapshots

Queries the Amazon EC2 API to return information on available Amazon EBS snapshots.
*/
public class DescribeSnapshots extends Choreography {

	/**
	Create a new instance of the DescribeSnapshots Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DescribeSnapshots(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/EC2/DescribeSnapshots"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DescribeSnapshotsInputSet
	*/
	public DescribeSnapshotsInputSet newInputSet() {
		return new DescribeSnapshotsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DescribeSnapshotsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DescribeSnapshotsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DescribeSnapshots
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DescribeSnapshotsInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the FilterName input for this Choreo. 

		@param String - (optional, string) The name of a supported filter to narrow results with.
		*/
		public void set_FilterName(String value) {
			this.setInput("FilterName", value);
		}


		/** 
		Set the value of the FilterValue input for this Choreo. 

		@param String - (optional, string) A value for the specified filter.
		*/
		public void set_FilterValue(String value) {
			this.setInput("FilterValue", value);
		}


		/** 
		Set the value of the Owner input for this Choreo. 

		@param String - (conditional, string) Returns the snapshots owned by the specified owner. Valid values are: "self" (the default), "amazon", or an AWS Account ID.
		*/
		public void set_Owner(String value) {
			this.setInput("Owner", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the RestorableBy input for this Choreo. 

		@param String - (optional, string) AWS accounts ID that can create volumes from the snapshot.
		*/
		public void set_RestorableBy(String value) {
			this.setInput("RestorableBy", value);
		}


		/** 
		Set the value of the SnapshotId input for this Choreo. 

		@param String - (optional, string) The ID of the snapshot you want to retrieve. Returns all snapshots if not specified.
		*/
		public void set_SnapshotId(String value) {
			this.setInput("SnapshotId", value);
		}


		/** 
		Set the value of the UserRegion input for this Choreo. 

		@param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
		*/
		public void set_UserRegion(String value) {
			this.setInput("UserRegion", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DescribeSnapshots Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DescribeSnapshotsResultSet extends ResultSet {
		public DescribeSnapshotsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Amazon.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
