package com.temboo.Library.Amazon.MachineLearning;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeleteBatchPrediction

Assigns the DELETED status to a BatchPrediction, rendering it unusable.
*/
public class DeleteBatchPrediction extends Choreography {

	/**
	Create a new instance of the DeleteBatchPrediction Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeleteBatchPrediction(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/MachineLearning/DeleteBatchPrediction"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeleteBatchPredictionInputSet
	*/
	public DeleteBatchPredictionInputSet newInputSet() {
		return new DeleteBatchPredictionInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeleteBatchPredictionResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeleteBatchPredictionResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeleteBatchPrediction
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeleteBatchPredictionInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the BatchPredictionId input for this Choreo. 

		@param String - (required, string) A user-supplied ID that uniquely identifies the BatchPrediction.
		*/
		public void set_BatchPredictionId(String value) {
			this.setInput("BatchPredictionId", value);
		}


		/** 
		Set the value of the UserRegion input for this Choreo. 

		@param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
		*/
		public void set_UserRegion(String value) {
			this.setInput("UserRegion", value);
		}


		/** 
		Set the value of the Verbose input for this Choreo. 

		@param Boolean - (optional, boolean) Specifies whether the GetDataSource operation should return DataSourceSchema. Defaults to true.
		*/
		public void set_Verbose(Boolean value) {
			this.setInput("Verbose", value);
		}

		/** 
		Set the value of the Verbose input for this Choreo as a String. 

		@param String - (optional, boolean) Specifies whether the GetDataSource operation should return DataSourceSchema. Defaults to true.
		*/
		public void set_Verbose(String value) {
			this.setInput("Verbose", value);	
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeleteBatchPrediction Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeleteBatchPredictionResultSet extends ResultSet {
		public DeleteBatchPredictionResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
