package com.temboo.Library.Basecamp;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateItem

Creates a new item for a specified To-do list.
*/
public class CreateItem extends Choreography {

	/**
	Create a new instance of the CreateItem Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateItem(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Basecamp/CreateItem"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateItemInputSet
	*/
	public CreateItemInputSet newInputSet() {
		return new CreateItemInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateItemResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateItemResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateItem
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateItemInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Basecamp account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}


		/** 
		Set the value of the Content input for this Choreo. 

		@param String - (required, string) The text of the item to create.
		*/
		public void set_Content(String value) {
			this.setInput("Content", value);
		}


		/** 
		Set the value of the ListID input for this Choreo. 

		@param Integer - (required, integer) The ID for the list in which to create the new item.
		*/
		public void set_ListID(Integer value) {
			this.setInput("ListID", value);
		}

		/** 
		Set the value of the ListID input for this Choreo as a String. 

		@param String - (required, integer) The ID for the list in which to create the new item.
		*/
		public void set_ListID(String value) {
			this.setInput("ListID", value);	
		}
		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Basecamp account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}


		/** 
		Set the value of the ResponsibleParty input for this Choreo. 

		@param Integer - (optional, integer) The user ID or company ID  (preceded by a “c”, as in "c1234") to assign the item to. Defaults to unassigned If left blank.
		*/
		public void set_ResponsibleParty(Integer value) {
			this.setInput("ResponsibleParty", value);
		}

		/** 
		Set the value of the ResponsibleParty input for this Choreo as a String. 

		@param String - (optional, integer) The user ID or company ID  (preceded by a “c”, as in "c1234") to assign the item to. Defaults to unassigned If left blank.
		*/
		public void set_ResponsibleParty(String value) {
			this.setInput("ResponsibleParty", value);	
		}
		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Basecamp account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateItem Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateItemResultSet extends ResultSet {
		public CreateItemResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - No structured response is returned from Basecamp for new item requests.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
