package com.temboo.Library.FedEx.Availability;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ServiceAvailability

Retrieves available shipping options and delivery dates for a specified origin and destination.
*/
public class ServiceAvailability extends Choreography {

	/**
	Create a new instance of the ServiceAvailability Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ServiceAvailability(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/FedEx/Availability/ServiceAvailability"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ServiceAvailabilityInputSet
	*/
	public ServiceAvailabilityInputSet newInputSet() {
		return new ServiceAvailabilityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ServiceAvailabilityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ServiceAvailabilityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ServiceAvailability
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ServiceAvailabilityInputSet extends InputSet {
		/** 
		Set the value of the AccountNumber input for this Choreo. 

		@param String - (required, string) Your FedEx Account Number or Test Account Number.
		*/
		public void set_AccountNumber(String value) {
			this.setInput("AccountNumber", value);
		}


		/** 
		Set the value of the AuthenticationKey input for this Choreo. 

		@param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
		*/
		public void set_AuthenticationKey(String value) {
			this.setInput("AuthenticationKey", value);
		}


		/** 
		Set the value of the DestinationCountryCode input for this Choreo. 

		@param String - (required, string) The destination country code to use for the service availability request (e.g., US).
		*/
		public void set_DestinationCountryCode(String value) {
			this.setInput("DestinationCountryCode", value);
		}


		/** 
		Set the value of the DestinationPostalCode input for this Choreo. 

		@param String - (required, string) The destination postal code to use for  the service availability request.
		*/
		public void set_DestinationPostalCode(String value) {
			this.setInput("DestinationPostalCode", value);
		}


		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}


		/** 
		Set the value of the MeterNumber input for this Choreo. 

		@param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
		*/
		public void set_MeterNumber(String value) {
			this.setInput("MeterNumber", value);
		}


		/** 
		Set the value of the OriginCountryCode input for this Choreo. 

		@param String - (required, string) The origin country code to use for the service availability request (e.g., US).
		*/
		public void set_OriginCountryCode(String value) {
			this.setInput("OriginCountryCode", value);
		}


		/** 
		Set the value of the OriginPostalCode input for this Choreo. 

		@param String - (required, string) The origin postal code to use for the service availability request.
		*/
		public void set_OriginPostalCode(String value) {
			this.setInput("OriginPostalCode", value);
		}


		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Production or Test Password provided by FedEx Web Services.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the ShipDate input for this Choreo. 

		@param String - (optional, date) The date to use for the service availability request. Dates should be formatted as YYYY-MM-DD. Defautls to today's date.
		*/
		public void set_ShipDate(String value) {
			this.setInput("ShipDate", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ServiceAvailability Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ServiceAvailabilityResultSet extends ResultSet {
		public ServiceAvailabilityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from FedEx.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
