package com.temboo.Library.InfluenceExplorer;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LocalBreakdown

Returns a breakdown of how much of the money raised was from contributors in the politician's state versus outside the politician's state.
*/
public class LocalBreakdown extends Choreography {

	/**
	Create a new instance of the LocalBreakdown Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LocalBreakdown(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/InfluenceExplorer/LocalBreakdown"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LocalBreakdownInputSet
	*/
	public LocalBreakdownInputSet newInputSet() {
		return new LocalBreakdownInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LocalBreakdownResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LocalBreakdownResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LocalBreakdown
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LocalBreakdownInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API key provided by Sunlight Data Services.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the EntityID input for this Choreo. 

		@param String - (required, string) The ID for the Entity that you want to return information for. This ID can be retrieved by running the SearchByName Choreo.
		*/
		public void set_EntityID(String value) {
			this.setInput("EntityID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LocalBreakdown Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LocalBreakdownResultSet extends ResultSet {
		public LocalBreakdownResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Influence Explorer.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
