package com.temboo.Library.Mixpanel.DataExport.Properties;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TopProperties

Gets the top property names for an event.
*/
public class TopProperties extends Choreography {

	/**
	Create a new instance of the TopProperties Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TopProperties(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Mixpanel/DataExport/Properties/TopProperties"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TopPropertiesInputSet
	*/
	public TopPropertiesInputSet newInputSet() {
		return new TopPropertiesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TopPropertiesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TopPropertiesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TopProperties
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TopPropertiesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the APISecret input for this Choreo. 

		@param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
		*/
		public void set_APISecret(String value) {
			this.setInput("APISecret", value);
		}


		/** 
		Set the value of the EventName input for this Choreo. 

		@param String - (required, string) The name of the event that you wish to get data for.
		*/
		public void set_EventName(String value) {
			this.setInput("EventName", value);
		}


		/** 
		Set the value of the Expire input for this Choreo. 

		@param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
		*/
		public void set_Expire(Integer value) {
			this.setInput("Expire", value);
		}

		/** 
		Set the value of the Expire input for this Choreo as a String. 

		@param String - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
		*/
		public void set_Expire(String value) {
			this.setInput("Expire", value);	
		}
		/** 
		Set the value of the Limit input for this Choreo. 

		@param Integer - (optional, integer) The maximum number of properties to return. Defaults to 10.
		*/
		public void set_Limit(Integer value) {
			this.setInput("Limit", value);
		}

		/** 
		Set the value of the Limit input for this Choreo as a String. 

		@param String - (optional, integer) The maximum number of properties to return. Defaults to 10.
		*/
		public void set_Limit(String value) {
			this.setInput("Limit", value);	
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TopProperties Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TopPropertiesResultSet extends ResultSet {
		public TopPropertiesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Mixpanel.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
