package com.temboo.Library.PagerDuty.Incidents;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ReassignIncident

Reassigns an incident.
*/
public class ReassignIncident extends Choreography {

	/**
	Create a new instance of the ReassignIncident Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ReassignIncident(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/PagerDuty/Incidents/ReassignIncident"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ReassignIncidentInputSet
	*/
	public ReassignIncidentInputSet newInputSet() {
		return new ReassignIncidentInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ReassignIncidentResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ReassignIncidentResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ReassignIncident
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ReassignIncidentInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by PagerDuty.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the AssignedToUser input for this Choreo. 

		@param String - (required, string) Assigns this incident to the specified user id.
		*/
		public void set_AssignedToUser(String value) {
			this.setInput("AssignedToUser", value);
		}


		/** 
		Set the value of the EscalationLevel input for this Choreo. 

		@param Integer - (optional, integer) Escalates the incident to this level in the escalation policy.
		*/
		public void set_EscalationLevel(Integer value) {
			this.setInput("EscalationLevel", value);
		}

		/** 
		Set the value of the EscalationLevel input for this Choreo as a String. 

		@param String - (optional, integer) Escalates the incident to this level in the escalation policy.
		*/
		public void set_EscalationLevel(String value) {
			this.setInput("EscalationLevel", value);	
		}
		/** 
		Set the value of the IncidentID input for this Choreo. 

		@param String - (required, string) The ID of the incident to reassign.
		*/
		public void set_IncidentID(String value) {
			this.setInput("IncidentID", value);
		}


		/** 
		Set the value of the RequesterID input for this Choreo. 

		@param String - (required, string) The ID of the user making the request. This will be added to the incident log entry.
		*/
		public void set_RequesterID(String value) {
			this.setInput("RequesterID", value);
		}


		/** 
		Set the value of the SubDomain input for this Choreo. 

		@param String - (required, string) The subdomain of your PagerDuty site address.
		*/
		public void set_SubDomain(String value) {
			this.setInput("SubDomain", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ReassignIncident Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ReassignIncidentResultSet extends ResultSet {
		public ReassignIncidentResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from PagerDuty.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
