package com.temboo.Library.Twitter.Lists;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateMember

Adds one or more members to a list.
*/
public class CreateMember extends Choreography {

	/**
	Create a new instance of the CreateMember Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateMember(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/Lists/CreateMember"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateMemberInputSet
	*/
	public CreateMemberInputSet newInputSet() {
		return new CreateMemberInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateMemberResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateMemberResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateMember
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateMemberInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (required, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}


		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (required, string) The API Key (or Consumer Key) provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}


		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (required, string) The API Secret (or Consumer Secret) provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}


		/** 
		Set the value of the ListId input for this Choreo. 

		@param String - (conditional, string) The numerical ID of the list. Required unless Slug is provided.
		*/
		public void set_ListId(String value) {
			this.setInput("ListId", value);
		}


		/** 
		Set the value of the OwnerId input for this Choreo. 

		@param String - (optional, string) The user ID of the user who owns the list being requested by a slug.
		*/
		public void set_OwnerId(String value) {
			this.setInput("OwnerId", value);
		}


		/** 
		Set the value of the OwnerScreenName input for this Choreo. 

		@param String - (optional, string) The screen name of the user who owns the list being requested by a slug.
		*/
		public void set_OwnerScreenName(String value) {
			this.setInput("OwnerScreenName", value);
		}


		/** 
		Set the value of the ScreenName input for this Choreo. 

		@param String - (conditional, string) The screen name of the user to add to the list. Required unless providing the UserId. Multiple screen names can be provided in a comma-separated list.
		*/
		public void set_ScreenName(String value) {
			this.setInput("ScreenName", value);
		}


		/** 
		Set the value of the Slug input for this Choreo. 

		@param String - (optional, string) When identifying a list by a slug, either OwnerScreenName or OwnerId must be provided.
		*/
		public void set_Slug(String value) {
			this.setInput("Slug", value);
		}


		/** 
		Set the value of the UserId input for this Choreo. 

		@param String - (conditional, string) The ID of the user to add to the list. Required unless providing the ScreenName. Multiple user IDs can be provided in a comma-separated list.
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateMember Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateMemberResultSet extends ResultSet {
		public CreateMemberResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
